==> s-verify-0.1.0.tgz: package/README.md <==
# s-verify

## 介绍

前端集合

## 安装

```
yarn add s-verify --save
# OR
npm install s-verify --save
```

## 使用

引用

import { sIDCard } from "s-verify";

调用

sIDCard("string",Boolean)

参数

|  方法名称   | 调用名称  |  说明  |  参数  |
|  ----  | ----  | ----  | ----  |
| 企业统一社会信用代码  | isEnterpriseCreditCode | 验证“企业统一社会信用代码” | 验证值（String）  |
| 身份证号  | isIDCard | 严格验证身份证号&返回身份信息 | 验证值（String）, 是否验证（Boolean）  |
| 邮箱  | isEmail | 严格邮箱 | 验证值（String）  |
| 电话号  | isTel | 验证电话号码 | 验证值（String,Number）  |
| 手机号  | isPhone | 验证手机号码 | 验证值（String,Number）  |
| 严格密码  | isStrictPassword | 密码以字母开头，长度在6~18之间，只能包含字母、数字和下划线 | 验证值（String）  |
| 邮政编码  | isPostal | 验证邮政编码 | 验证值（String）  |
| 日期时间  | isDate | 验证日期时间 | 验证值（String）  |
| 英文  | isEnglish | 验证英文 | 验证值（String）  |
| 中文  | isChinese | 验证中文 | 验证值（String）  |
| 小写  | isLower | 验证小写 | 验证值（String）  |
| 大写  | isUpper | 验证大写 | 验证值（String）  |
| 网址  | isUrl | 验证网址 | 验证值（String）  |
| 字符串  | isString | 验证字符串 | 验证值（*）  |
| 数字  | isNumber | 验证数字 | 验证值（*）  |
| 布尔  | isBoolean | 验证布尔 | 验证值（*）  |
| 函数  | isFunction | 验证函数 | 验证值（*）  |
| null  | isNull | 验证null | 验证值（*）  |
| undefined  | isUndefined | 验证undefined | 验证值（*）  |
| object  | isObject | 验证Object | 验证值（*）  |
| array  | isArray | 验证Array | 验证值（*）  |
| Symbol函数  | isSymbol | 验证Symbol函数 | 验证值（*）  |
| Promise对象  | isPromise | 验证Promise对象 | 验证值（*）  |
| Set对象  | isSet | 验证Set对象 | 验证值（*）  |
| 微信浏览器  | isWeiXin | 验证是否是微信浏览器 |  -  |
| 移动端  | isDeviceMobile | 验证是否是移动端 |  -  |
| QQ浏览器  | isQQBrowser | 验证是否是QQ浏览器 |  -  |
| 爬虫  | isSpider | 验证是否是爬虫 |  -  |
| Ios  | isIos | 验证是否是Ios系统 |  -  |
| Pc  | isPC | 验证是否是Pc端 |  -  |

==> s-verify-0.1.1.tgz: package/README.md <==
# s-verify

## 介绍

前端集合

## 安装

```
yarn add s-verify --save
# OR
npm install s-verify --save
```

## 使用

引用

import { sIDCard } from "s-verify";

调用

sIDCard("string",Boolean)

参数

|  方法名称   | 调用名称  |  说明  |  参数  |
|  ----  | ----  | ----  | ----  |
| 企业统一社会信用代码  | isEnterpriseCreditCode | 验证“企业统一社会信用代码” | 验证值（String）  |
| 身份证号  | isIDCard | 严格验证身份证号&返回身份信息 | 验证值（String）, 是否验证（Boolean）  |
| 邮箱  | isEmail | 验证邮箱 | 验证值（String）  |
| 车牌号  | isCarNumber | 验证车牌号 | 验证值（String）  |
| 电话号  | isTel | 验证电话号码 | 验证值（String,Number）  |
| 手机号  | isPhone | 验证手机号码 | 验证值（String,Number）  |
| 严格密码  | isStrictPassword | 密码以字母开头，长度在6~18之间，只能包含字母、数字和下划线 | 验证值（String）  |
| 邮政编码  | isPostal | 验证邮政编码 | 验证值（String）  |
| 日期时间  | isDate | 验证日期时间 | 验证值（String）  |
| 英文  | isEnglish | 验证英文 | 验证值（String）  |
| 中文  | isChinese | 验证中文 | 验证值（String）  |
| 小写  | isLower | 验证小写 | 验证值（String）  |
| 大写  | isUpper | 验证大写 | 验证值（String）  |
| 网址  | isUrl | 验证网址 | 验证值（String）  |
| 字符串  | isString | 验证字符串 | 验证值（*）  |
| 数字  | isNumber | 验证数字 | 验证值（*）  |
| 布尔  | isBoolean | 验证布尔 | 验证值（*）  |
| 函数  | isFunction | 验证函数 | 验证值（*）  |
| null  | isNull | 验证null | 验证值（*）  |
| undefined  | isUndefined | 验证undefined | 验证值（*）  |
| object  | isObject | 验证Object | 验证值（*）  |
| array  | isArray | 验证Array | 验证值（*）  |
| Symbol函数  | isSymbol | 验证Symbol函数 | 验证值（*）  |
| Promise对象  | isPromise | 验证Promise对象 | 验证值（*）  |
| Set对象  | isSet | 验证Set对象 | 验证值（*）  |
| 微信浏览器  | isWeiXin | 验证是否是微信浏览器 |  -  |
| 移动端  | isDeviceMobile | 验证是否是移动端 |  -  |
| QQ浏览器  | isQQBrowser | 验证是否是QQ浏览器 |  -  |
| 爬虫  | isSpider | 验证是否是爬虫 |  -  |
| Ios  | isIos | 验证是否是Ios系统 |  -  |
| Pc  | isPC | 验证是否是Pc端 |  -  |
